@@ -21,6 +21,7 @@ an ACL object under the hood, and you can interact with that using
 .. literalinclude:: snippets.py
     :start-after: [START client_bucket_acl]
     :end-before: [END client_bucket_acl]
+    :dedent: 4
 
 
 Adding and removing permissions can be done with the following methods
@@ -52,6 +53,7 @@ be :class:`_ACLEntity` factories):
 .. literalinclude:: snippets.py
    :start-after: [START acl_user_settings]
    :end-before: [END acl_user_settings]
+   :dedent: 4
 
 After that, you can save any changes you make with the
 :func:`google.cloud.storage.acl.ACL.save` method:
@@ -59,6 +61,7 @@ After that, you can save any changes you make with the
 .. literalinclude:: snippets.py
    :start-after: [START acl_save]
    :end-before: [END acl_save]
+   :dedent: 4
 
 You can alternatively save any existing :class:`google.cloud.storage.acl.ACL`
 object (whether it was created by a factory method or not) from a
@@ -67,6 +70,7 @@ object (whether it was created by a factory method or not) from a
 .. literalinclude:: snippets.py
    :start-after: [START acl_save_bucket]
    :end-before: [END acl_save_bucket]
+   :dedent: 4
 
 To get the list of ``entity`` and ``role`` for each unique pair, the
 :class:`ACL` class is iterable:
@@ -74,12 +78,14 @@ To get the list of ``entity`` and ``role`` for each unique pair, the
 .. literalinclude:: snippets.py
    :start-after: [START acl_print]
    :end-before: [END acl_print]
+   :dedent: 4
 
 This list of tuples can be used as the ``entity`` and ``role`` fields
 when sending metadata for ACLs to the API.
 """
 
 from google.cloud.storage.constants import _DEFAULT_TIMEOUT
+from google.cloud.storage.retry import DEFAULT_RETRY
 
 
 class _ACLEntity(object):
@@ -92,8 +98,8 @@ class _ACLEntity(object):
     :param entity_type: The type of entity (ie, 'group' or 'user').
 
     :type identifier: str
-    :param identifier: The ID or e-mail of the entity. For the special
-                       entity types (like 'allUsers') this is optional.
+    :param identifier: (Optional) The ID or e-mail of the entity. For the special
+                       entity types (like 'allUsers').
     """
 
     READER_ROLE = "READER"
@@ -201,6 +207,7 @@ class ACL(object):
 
     # Subclasses must override to provide these attributes (typically,
     # as properties).
+    client = None
     reload_path = None
     save_path = None
     user_project = None
@@ -212,11 +219,9 @@ class ACL(object):
         """Load if not already loaded.
 
         :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
-
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
         """
         if not self.loaded:
             self.reload(timeout=timeout)
@@ -425,21 +430,23 @@ class ACL(object):
             client = self.client
         return client
 
-    def reload(self, client=None, timeout=_DEFAULT_TIMEOUT):
+    def reload(self, client=None, timeout=_DEFAULT_TIMEOUT, retry=DEFAULT_RETRY):
         """Reload the ACL data from Cloud Storage.
 
         If :attr:`user_project` is set, bills the API request to that project.
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the ACL's parent.
         :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type retry: :class:`~google.api_core.retry.Retry`
+        :param retry:
+            (Optional) How to retry the RPC. See: :ref:`configuring_retries`
         """
         path = self.reload_path
         client = self._require_client(client)
@@ -450,10 +457,11 @@ class ACL(object):
 
         self.entities.clear()
 
-        found = client._connection.api_request(
-            method="GET", path=path, query_params=query_params, timeout=timeout
+        found = client._get_resource(
+            path, query_params=query_params, timeout=timeout, retry=retry,
         )
         self.loaded = True
+
         for entry in found.get("items", ()):
             self.add_entity(self.entity_from_dict(entry))
 
@@ -465,22 +473,26 @@ class ACL(object):
                     current entries.
 
         :type predefined: str
-        :param predefined:
-            (Optional) An identifier for a predefined ACL.  Must be one of the
+        :param predefined: An identifier for a predefined ACL.  Must be one of the
             keys in :attr:`PREDEFINED_JSON_ACLS` If passed, `acl` must be None.
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the ACL's parent.
-        :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type timeout: float or tuple
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
+
+        :type retry: :class:`~google.api_core.retry.Retry`
+        :param retry:
+            (Optional) How to retry the RPC. See: :ref:`configuring_retries`
         """
+        client = self._require_client(client)
         query_params = {"projection": "full"}
+
         if predefined is not None:
             acl = []
             query_params[self._PREDEFINED_QUERY_PARAM] = predefined
@@ -489,18 +501,20 @@ class ACL(object):
             query_params["userProject"] = self.user_project
 
         path = self.save_path
-        client = self._require_client(client)
 
-        result = client._connection.api_request(
-            method="PATCH",
-            path=path,
-            data={self._URL_PATH_ELEM: list(acl)},
+        result = client._patch_resource(
+            path,
+            {self._URL_PATH_ELEM: list(acl)},
             query_params=query_params,
             timeout=timeout,
+            retry=None,
         )
+
         self.entities.clear()
+
         for entry in result.get(self._URL_PATH_ELEM, ()):
             self.add_entity(self.entity_from_dict(entry))
+
         self.loaded = True
 
     def save(self, acl=None, client=None, timeout=_DEFAULT_TIMEOUT):
@@ -514,14 +528,13 @@ class ACL(object):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the ACL's parent.
-        :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type timeout: float or tuple
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
         """
         if acl is None:
             acl = self
@@ -546,14 +559,13 @@ class ACL(object):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the ACL's parent.
-        :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type timeout: float or tuple
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
         """
         predefined = self.validate_predefined(predefined)
         self._save(None, predefined, client, timeout=timeout)
@@ -570,14 +582,13 @@ class ACL(object):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the ACL's parent.
-        :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type timeout: float or tuple
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
         """
         self.save([], client=client, timeout=timeout)
 
