@@ -19,6 +19,7 @@ import re
 from google.api_core.exceptions import NotFound
 
 from google.cloud.storage.constants import _DEFAULT_TIMEOUT
+from google.cloud.storage.retry import DEFAULT_RETRY
 
 
 OBJECT_FINALIZE_EVENT_TYPE = "OBJECT_FINALIZE"
@@ -50,40 +51,46 @@ class BucketNotification(object):
     :param bucket: Bucket to which the notification is bound.
 
     :type topic_name: str
-    :param topic_name: Topic name to which notifications are published.
+    :param topic_name:
+        (Optional) Topic name to which notifications are published.
 
     :type topic_project: str
     :param topic_project:
-        (Optional) project ID of topic to which notifications are published.
+        (Optional) Project ID of topic to which notifications are published.
         If not passed, uses the project ID of the bucket's client.
 
     :type custom_attributes: dict
     :param custom_attributes:
-        (Optional) additional attributes passed with notification events.
+        (Optional) Additional attributes passed with notification events.
 
     :type event_types: list(str)
     :param event_types:
-        (Optional) event types for which notificatin events are published.
+        (Optional) Event types for which notification events are published.
 
     :type blob_name_prefix: str
     :param blob_name_prefix:
-        (Optional) prefix of blob names for which notification events are
-        published..
+        (Optional) Prefix of blob names for which notification events are
+        published.
 
     :type payload_format: str
     :param payload_format:
-        (Optional) format of payload for notification events.
+        (Optional) Format of payload for notification events.
+
+    :type notification_id: str
+    :param notification_id:
+        (Optional) The ID of the notification.
     """
 
     def __init__(
         self,
         bucket,
-        topic_name,
+        topic_name=None,
         topic_project=None,
         custom_attributes=None,
         event_types=None,
         blob_name_prefix=None,
         payload_format=NONE_PAYLOAD_FORMAT,
+        notification_id=None,
     ):
         self._bucket = bucket
         self._topic_name = topic_name
@@ -107,6 +114,9 @@ class BucketNotification(object):
         if blob_name_prefix is not None:
             self._properties["object_name_prefix"] = blob_name_prefix
 
+        if notification_id is not None:
+            self._properties["id"] = notification_id
+
         self._properties["payload_format"] = payload_format
 
     @classmethod
@@ -223,7 +233,7 @@ class BucketNotification(object):
         self._properties.clear()
         self._properties.update(response)
 
-    def create(self, client=None, timeout=_DEFAULT_TIMEOUT):
+    def create(self, client=None, timeout=_DEFAULT_TIMEOUT, retry=None):
         """API wrapper: create the notification.
 
         See:
@@ -233,14 +243,16 @@ class BucketNotification(object):
         to that project.
 
         :type client: :class:`~google.cloud.storage.client.Client`
-        :param client: (Optional) the client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the notification's bucket.
         :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type retry: google.api_core.retry.Retry or google.cloud.storage.retry.ConditionalRetryPolicy
+        :param retry:
+            (Optional) How to retry the RPC. See: :ref:`configuring_retries`
         """
         if self.notification_id is not None:
             raise ValueError(
@@ -256,15 +268,11 @@ class BucketNotification(object):
         path = "/b/{}/notificationConfigs".format(self.bucket.name)
         properties = self._properties.copy()
         properties["topic"] = _TOPIC_REF_FMT.format(self.topic_project, self.topic_name)
-        self._properties = client._connection.api_request(
-            method="POST",
-            path=path,
-            query_params=query_params,
-            data=properties,
-            timeout=timeout,
+        self._properties = client._post_resource(
+            path, properties, query_params=query_params, timeout=timeout, retry=retry,
         )
 
-    def exists(self, client=None, timeout=_DEFAULT_TIMEOUT):
+    def exists(self, client=None, timeout=_DEFAULT_TIMEOUT, retry=DEFAULT_RETRY):
         """Test whether this notification exists.
 
         See:
@@ -275,14 +283,16 @@ class BucketNotification(object):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the current bucket.
         :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type retry: google.api_core.retry.Retry or google.cloud.storage.retry.ConditionalRetryPolicy
+        :param retry:
+            (Optional) How to retry the RPC. See: :ref:`configuring_retries`
 
         :rtype: bool
         :returns: True, if the notification exists, else False.
@@ -298,15 +308,15 @@ class BucketNotification(object):
             query_params["userProject"] = self.bucket.user_project
 
         try:
-            client._connection.api_request(
-                method="GET", path=self.path, query_params=query_params, timeout=timeout
+            client._get_resource(
+                self.path, query_params=query_params, timeout=timeout, retry=retry,
             )
         except NotFound:
             return False
         else:
             return True
 
-    def reload(self, client=None, timeout=_DEFAULT_TIMEOUT):
+    def reload(self, client=None, timeout=_DEFAULT_TIMEOUT, retry=DEFAULT_RETRY):
         """Update this notification from the server configuration.
 
         See:
@@ -317,17 +327,18 @@ class BucketNotification(object):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the current bucket.
         :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
+
+        :type retry: google.api_core.retry.Retry or google.cloud.storage.retry.ConditionalRetryPolicy
+        :param retry:
+            (Optional) How to retry the RPC. See: :ref:`configuring_retries`
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
 
-        :rtype: bool
-        :returns: True, if the notification exists, else False.
         :raises ValueError: if the notification has no ID.
         """
         if self.notification_id is None:
@@ -339,12 +350,12 @@ class BucketNotification(object):
         if self.bucket.user_project is not None:
             query_params["userProject"] = self.bucket.user_project
 
-        response = client._connection.api_request(
-            method="GET", path=self.path, query_params=query_params, timeout=timeout
+        response = client._get_resource(
+            self.path, query_params=query_params, timeout=timeout, retry=retry,
         )
         self._set_properties(response)
 
-    def delete(self, client=None, timeout=_DEFAULT_TIMEOUT):
+    def delete(self, client=None, timeout=_DEFAULT_TIMEOUT, retry=DEFAULT_RETRY):
         """Delete this notification.
 
         See:
@@ -355,14 +366,16 @@ class BucketNotification(object):
 
         :type client: :class:`~google.cloud.storage.client.Client` or
                       ``NoneType``
-        :param client: Optional. The client to use.  If not passed, falls back
+        :param client: (Optional) The client to use.  If not passed, falls back
                        to the ``client`` stored on the current bucket.
         :type timeout: float or tuple
-        :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response.
+        :param timeout:
+            (Optional) The amount of time, in seconds, to wait
+            for the server response.  See: :ref:`configuring_timeouts`
 
-            Can also be passed as a tuple (connect_timeout, read_timeout).
-            See :meth:`requests.Session.request` documentation for details.
+        :type retry: google.api_core.retry.Retry or google.cloud.storage.retry.ConditionalRetryPolicy
+        :param retry:
+            (Optional) How to retry the RPC. See: :ref:`configuring_retries`
 
         :raises: :class:`google.api_core.exceptions.NotFound`:
             if the notification does not exist.
@@ -377,8 +390,8 @@ class BucketNotification(object):
         if self.bucket.user_project is not None:
             query_params["userProject"] = self.bucket.user_project
 
-        client._connection.api_request(
-            method="DELETE", path=self.path, query_params=query_params, timeout=timeout
+        client._delete_resource(
+            self.path, query_params=query_params, timeout=timeout, retry=retry,
         )
 
 
